@@ -12,7 +12,7 @@ from tabulator.parsers.csv import CSVParser
 BASE_URL = 'https://raw.githubusercontent.com/okfn/tabulator-py/master/%s'
 
 
-# Stream
+# Read
 
 def test_stream_local_csv():
     with Stream('data/table.csv') as stream:
@@ -80,12 +80,14 @@ def test_stream_text_csv():
         assert stream.read() == [['id', 'name'], ['1', 'english'], ['2', '中国人']]
 
 
+@pytest.mark.remote
 def test_stream_remote_csv():
     with Stream(BASE_URL % 'data/table.csv') as stream:
         assert stream.headers is None
         assert stream.read() == [['id', 'name'], ['1', 'english'], ['2', '中国人']]
 
 
+@pytest.mark.remote
 def test_stream_remote_csv_non_ascii_url():
     with Stream('http://data.defra.gov.uk/ops/government_procurement_card/over_£500_GPC_apr_2013.csv') as stream:
         assert stream.sample[0] == [
@@ -153,7 +155,22 @@ def test_stream_csv_quotechar_is_empty_string():
         stream.read() == ['value1', 'value2"', 'value3']
 
 
-# Parser
+# Write
+
+def test_stream_save_csv(tmpdir):
+    source = 'data/table.csv'
+    target = str(tmpdir.join('table.csv'))
+    with Stream(source, headers=1) as stream:
+        assert stream.save(target) == 2
+    with Stream(target, headers=1) as stream:
+        assert stream.headers == ['id', 'name']
+        assert stream.read(extended=True) == [
+            (2, ['id', 'name'], ['1', 'english']),
+            (3, ['id', 'name'], ['2', '中国人']),
+        ]
+
+
+# Internal
 
 def test_parser_csv():
 
