@@ -12,13 +12,7 @@ from tabulator.parsers.xlsx import XLSXParser
 BASE_URL = 'https://raw.githubusercontent.com/okfn/tabulator-py/master/%s'
 
 
-# Stream
-
-def test_stream_xlsx_remote():
-    source = BASE_URL % 'data/table.xlsx'
-    with Stream(source) as stream:
-        assert stream.read() == [['id', 'name'], [1.0, 'english'], [2.0, '中国人']]
-
+# Read
 
 def test_stream_xlsx_stream():
     source = io.open('data/table.xlsx', mode='rb')
@@ -27,6 +21,13 @@ def test_stream_xlsx_stream():
         assert stream.read() == [['id', 'name'], [1.0, 'english'], [2.0, '中国人']]
 
 
+@pytest.mark.remote
+def test_stream_xlsx_remote():
+    source = BASE_URL % 'data/table.xlsx'
+    with Stream(source) as stream:
+        assert stream.read() == [['id', 'name'], [1.0, 'english'], [2.0, '中国人']]
+
+
 def test_stream_xlsx_sheet_by_index():
     source = 'data/special/sheet2.xlsx'
     with Stream(source, sheet=2) as stream:
@@ -112,7 +113,33 @@ def test_stream_xlsx_preserve_formatting():
         }]
 
 
-# Parser
+# Write
+
+def test_stream_save_xlsx(tmpdir):
+    source = 'data/table.csv'
+    target = str(tmpdir.join('table.xlsx'))
+    with Stream(source, headers=1) as stream:
+        assert stream.save(target) == 2
+    with Stream(target, headers=1) as stream:
+        assert stream.headers == ['id', 'name']
+        assert stream.read(extended=True) == [
+            (2, ['id', 'name'], ['1', 'english']),
+            (3, ['id', 'name'], ['2', '中国人'])]
+
+
+def test_stream_save_xlsx_sheet_name(tmpdir):
+    source = 'data/table.csv'
+    target = str(tmpdir.join('table.xlsx'))
+    with Stream(source, headers=1) as stream:
+        assert stream.save(target, sheet='my-data') == 2
+    with Stream(target, headers=1, sheet='my-data') as stream:
+        assert stream.headers == ['id', 'name']
+        assert stream.read(extended=True) == [
+            (2, ['id', 'name'], ['1', 'english']),
+            (3, ['id', 'name'], ['2', '中国人'])]
+
+
+# Internal
 
 def test_parser_xlsx():
 
